@@ -10,4 +10,11 @@ POST = 'POST'
 DELETE = 'DELETE'
 METHODS = (GET, PUT, POST, DELETE)
 
+TOLERATED_RESPONSE_CODES = {
+    GET: [],
+    PUT: [],
+    POST: [],
+    DELETE: [500, 503]
+}
+
 DEFAULT_METHOD = GET
